deploy_builder

pub fn deploy_builder<P, N>(
    __provider: P,
    _antToken: Address,
    _batchLimit: Uint<256, 4>,
) -> CallBuilder<P, (), N>
where P: Provider<N>, N: Network,
Creates a RawCallBuilder for deploying this contract using the given provider and constructor arguments, if any.

This is a simple wrapper around creating a RawCallBuilder with the data set to the bytecode concatenated with the constructor’s ABI-encoded arguments.