pub struct PaymentAlreadyExists {
pub winnerPoolHash: FixedBytes<32>,
}Expand description
Custom error with signature PaymentAlreadyExists(bytes32) and selector 0x9d8c19ed.
error PaymentAlreadyExists(bytes32 winnerPoolHash);Fields
winnerPoolHash: FixedBytes<32>Trait Implementations
Sourceimpl Clone for PaymentAlreadyExists
impl Clone for PaymentAlreadyExists
Sourcefn clone(&self) -> PaymentAlreadyExists
fn clone(&self) -> PaymentAlreadyExists
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolError for PaymentAlreadyExists
impl SolError for PaymentAlreadyExists
Sourcetype Parameters<'a> = (FixedBytes<32>,)
type Parameters<'a> = (FixedBytes<32>,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<PaymentAlreadyExists as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<PaymentAlreadyExists as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<PaymentAlreadyExists as SolError>::Parameters<'a> as SolType>::RustType,
) -> PaymentAlreadyExists
fn new<'a>( tuple: <<PaymentAlreadyExists as SolError>::Parameters<'a> as SolType>::RustType, ) -> PaymentAlreadyExists
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <PaymentAlreadyExists as SolError>::Token<'_>
fn tokenize(&self) -> <PaymentAlreadyExists as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<PaymentAlreadyExists, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<PaymentAlreadyExists, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.