pub struct WrongPoolCount {
pub expected: Uint<256, 4>,
pub actual: Uint<256, 4>,
}Expand description
Custom error with signature WrongPoolCount(uint256,uint256) and selector 0x8ffc236a.
error WrongPoolCount(uint256 expected, uint256 actual);Fields
expected: Uint<256, 4>actual: Uint<256, 4>Trait Implementations
Sourceimpl Clone for WrongPoolCount
impl Clone for WrongPoolCount
Sourcefn clone(&self) -> WrongPoolCount
fn clone(&self) -> WrongPoolCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolError for WrongPoolCount
impl SolError for WrongPoolCount
Sourcetype Parameters<'a> = (Uint<256>, Uint<256>)
type Parameters<'a> = (Uint<256>, Uint<256>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<WrongPoolCount as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<WrongPoolCount as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<WrongPoolCount as SolError>::Parameters<'a> as SolType>::RustType,
) -> WrongPoolCount
fn new<'a>( tuple: <<WrongPoolCount as SolError>::Parameters<'a> as SolType>::RustType, ) -> WrongPoolCount
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <WrongPoolCount as SolError>::Token<'_>
fn tokenize(&self) -> <WrongPoolCount as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<WrongPoolCount, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<WrongPoolCount, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.