pub struct completedPaymentsCall(pub FixedBytes<32>);Expand description
Function with signature completedPayments(bytes32) and selector 0xfe3c806e.
function completedPayments(bytes32) external view returns (bytes16 rewardsAddress, uint128 amount);Tuple Fields
0: FixedBytes<32>Trait Implementations
Sourceimpl Clone for completedPaymentsCall
impl Clone for completedPaymentsCall
Sourcefn clone(&self) -> completedPaymentsCall
fn clone(&self) -> completedPaymentsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for completedPaymentsCall
impl SolCall for completedPaymentsCall
Sourcetype Parameters<'a> = (FixedBytes<32>,)
type Parameters<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<completedPaymentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<completedPaymentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = completedPaymentsReturn
type Return = completedPaymentsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<16>, Uint<128>)
type ReturnTuple<'a> = (FixedBytes<16>, Uint<128>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<completedPaymentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<completedPaymentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<completedPaymentsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> completedPaymentsCall
fn new<'a>( tuple: <<completedPaymentsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> completedPaymentsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <completedPaymentsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <completedPaymentsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<completedPaymentsCall as SolCall>::Return,
) -> <completedPaymentsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<completedPaymentsCall as SolCall>::Return, ) -> <completedPaymentsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<completedPaymentsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<completedPaymentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<completedPaymentsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<completedPaymentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.