pub struct DepthTooLarge {
pub depth: u8,
pub maxDepth: u8,
}Expand description
Custom error with signature DepthTooLarge(uint8,uint8) and selector 0x2c96be06.
error DepthTooLarge(uint8 depth, uint8 maxDepth);Fields
depth: u8maxDepth: u8Trait Implementations
Sourceimpl Clone for DepthTooLarge
impl Clone for DepthTooLarge
Sourcefn clone(&self) -> DepthTooLarge
fn clone(&self) -> DepthTooLarge
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DepthTooLarge
impl Debug for DepthTooLarge
Sourceimpl SolError for DepthTooLarge
impl SolError for DepthTooLarge
Sourcetype Parameters<'a> = (Uint<8>, Uint<8>)
type Parameters<'a> = (Uint<8>, Uint<8>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<DepthTooLarge as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<DepthTooLarge as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<DepthTooLarge as SolError>::Parameters<'a> as SolType>::RustType,
) -> DepthTooLarge
fn new<'a>( tuple: <<DepthTooLarge as SolError>::Parameters<'a> as SolType>::RustType, ) -> DepthTooLarge
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <DepthTooLarge as SolError>::Token<'_>
fn tokenize(&self) -> <DepthTooLarge as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<DepthTooLarge, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<DepthTooLarge, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.