pub struct payForMerkleTreeCall {
pub depth: u8,
pub poolCommitments: Vec<<PoolCommitment as SolType>::RustType>,
pub merklePaymentTimestamp: u64,
}Expand description
Function with signature payForMerkleTree(uint8,(bytes32,(address,uint256)[16])[],uint64) and selector 0x5460f240.
function payForMerkleTree(uint8 depth, PoolCommitment[] memory poolCommitments, uint64 merklePaymentTimestamp) external returns (bytes32 winnerPoolHash, uint256 totalAmount);Fields
depth: u8poolCommitments: Vec<<PoolCommitment as SolType>::RustType>merklePaymentTimestamp: u64Trait Implementations
Sourceimpl Clone for payForMerkleTreeCall
impl Clone for payForMerkleTreeCall
Sourcefn clone(&self) -> payForMerkleTreeCall
fn clone(&self) -> payForMerkleTreeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for payForMerkleTreeCall
impl Debug for payForMerkleTreeCall
Sourceimpl SolCall for payForMerkleTreeCall
impl SolCall for payForMerkleTreeCall
Sourceconst SIGNATURE: &'static str = "payForMerkleTree(uint8,(bytes32,(address,uint256)[16])[],uint64)"
const SIGNATURE: &'static str = "payForMerkleTree(uint8,(bytes32,(address,uint256)[16])[],uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<8>, Array<PoolCommitment>, Uint<64>)
type Parameters<'a> = (Uint<8>, Array<PoolCommitment>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<payForMerkleTreeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<payForMerkleTreeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = payForMerkleTreeReturn
type Return = payForMerkleTreeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>, Uint<256>)
type ReturnTuple<'a> = (FixedBytes<32>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<payForMerkleTreeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<payForMerkleTreeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<payForMerkleTreeCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> payForMerkleTreeCall
fn new<'a>( tuple: <<payForMerkleTreeCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> payForMerkleTreeCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <payForMerkleTreeCall as SolCall>::Token<'_>
fn tokenize(&self) -> <payForMerkleTreeCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<payForMerkleTreeCall as SolCall>::Return,
) -> <payForMerkleTreeCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<payForMerkleTreeCall as SolCall>::Return, ) -> <payForMerkleTreeCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<payForMerkleTreeCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<payForMerkleTreeCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<payForMerkleTreeCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<payForMerkleTreeCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.