pub enum PaymentRequest {
Quotes(Vec<(FixedBytes<32>, Address, Uint<256, 4>)>),
Merkle {
depth: u8,
pools: Vec<PoolCommitment>,
timestamp: u64,
},
}Expand description
An ordinary single transaction payment, using the existing vault encoders.
Variants
Quotes(Vec<(FixedBytes<32>, Address, Uint<256, 4>)>)
At most one vault transaction of nonzero quote payments.
Merkle
One Merkle sub-batch.