pub fn set_network_id(id: u8)Expand description
Update the NETWORK_ID.
Other version strings will reference this value. The default is 1, representing the mainnet.
This function should be used sparingly, ideally before the node or client is started.
Each of the version strings need to be explicitly updated here. There are scenarios where they could be read before this function is called, in which case they will have the old value for the lifetime of the program.