pub fn get_min_node_version() -> PeerVersionExpand description
Get the minimum node version, checking environment variable override first.
Environment variable format: ANT_MIN_NODE_VERSION=0.4.14
pub fn get_min_node_version() -> PeerVersionGet the minimum node version, checking environment variable override first.
Environment variable format: ANT_MIN_NODE_VERSION=0.4.14