pub struct PaymentVaultHandler<P, N>{
pub contract: IPaymentVaultInstance<P, N>,
}Fields
contract: IPaymentVaultInstance<P, N>Implementations
Sourceimpl<P, N> PaymentVaultHandler<P, N>
impl<P, N> PaymentVaultHandler<P, N>
Sourcepub fn new(contract_address: Address, provider: P) -> PaymentVaultHandler<P, N>
pub fn new(contract_address: Address, provider: P) -> PaymentVaultHandler<P, N>
Create a new PaymentVaultHandler instance from a (proxy) contract’s address
Sourcepub fn set_provider(&mut self, provider: P)
pub fn set_provider(&mut self, provider: P)
Set the provider
Sourcepub async fn pay_for_quotes<I>(
&self,
data_payments: I,
transaction_config: &TransactionConfig,
) -> Result<(FixedBytes<32>, GasInfo), Error>
pub async fn pay_for_quotes<I>( &self, data_payments: I, transaction_config: &TransactionConfig, ) -> Result<(FixedBytes<32>, GasInfo), Error>
Pay for quotes. Returns the transaction hash and gas information.
Sourcepub fn pay_for_quotes_calldata<I>(
&self,
data_payments: I,
) -> Result<(Bytes, Address), Error>
pub fn pay_for_quotes_calldata<I>( &self, data_payments: I, ) -> Result<(Bytes, Address), Error>
Returns the pay for quotes transaction calldata.
Sourcepub async fn pay_for_merkle_tree<I, T>(
&self,
depth: u8,
pool_commitments: I,
merkle_payment_timestamp: u64,
transaction_config: &TransactionConfig,
) -> Result<([u8; 32], Uint<256, 4>, GasInfo), Error>
pub async fn pay_for_merkle_tree<I, T>( &self, depth: u8, pool_commitments: I, merkle_payment_timestamp: u64, transaction_config: &TransactionConfig, ) -> Result<([u8; 32], Uint<256, 4>, GasInfo), Error>
Pay for Merkle tree batch.
Sends payForMerkleTree with unpacked PoolCommitment structs (candidates have price).
Returns
- Tuple of (winner pool hash, total amount paid, gas info)
Sourcepub fn pay_for_merkle_tree_calldata<I, T>(
&self,
depth: u8,
pool_commitments: I,
merkle_payment_timestamp: u64,
) -> Result<(Bytes, Address), Error>
pub fn pay_for_merkle_tree_calldata<I, T>( &self, depth: u8, pool_commitments: I, merkle_payment_timestamp: u64, ) -> Result<(Bytes, Address), Error>
Get calldata for payForMerkleTree.
Public so external signers can generate calldata without a wallet.
Sourcepub async fn get_completed_merkle_payment(
&self,
winner_pool_hash: [u8; 32],
) -> Result<CompletedMerklePayment, Error>
pub async fn get_completed_merkle_payment( &self, winner_pool_hash: [u8; 32], ) -> Result<CompletedMerklePayment, Error>
Get completed merkle payment info for a winner pool hash.
Calls getCompletedMerklePayment on the contract, which returns
CompletedMerklePayment containing depth, timestamp, and paid nodes
(each with rewards address, pool index, and amount).