pub struct MerklePaymentProof {
pub address: XorName,
pub data_proof: MerkleBranch,
pub winner_pool: MerklePaymentCandidatePool,
}Expand description
Data package for merkle payment verification.
Contains everything a node needs to verify a merkle batch payment.
Fields
address: XorNameThe data’s XorName
data_proof: MerkleBranchMerkle proof that this data belongs to the paid tree
winner_pool: MerklePaymentCandidatePoolThe winner pool selected by the smart contract
Implementations
Sourceimpl MerklePaymentProof
impl MerklePaymentProof
Sourcepub fn new(
address: XorName,
data_proof: MerkleBranch,
winner_pool: MerklePaymentCandidatePool,
) -> MerklePaymentProof
pub fn new( address: XorName, data_proof: MerkleBranch, winner_pool: MerklePaymentCandidatePool, ) -> MerklePaymentProof
Create a new Merkle payment proof.
Sourcepub fn winner_pool_hash(&self) -> [u8; 32]
pub fn winner_pool_hash(&self) -> [u8; 32]
Get the hash of the winner pool (used to query smart contract for payment info).