pub struct PaymentQuote {
pub content: XorName,
pub timestamp: SystemTime,
pub price: Uint<256, 4>,
pub rewards_address: Address,
pub pub_key: Vec<u8>,
pub signature: Vec<u8>,
}Expand description
A payment quote to store data given by a node to a client.
The PaymentQuote is a contract between the node and itself to make sure the clients aren’t mispaying. It is NOT a contract between the client and the node.
Fields
content: XorNameThe content paid for
timestamp: SystemTimeThe local node time when the quote was created
price: Uint<256, 4>The node-calculated price for storing this content
rewards_address: AddressThe node’s wallet address
pub_key: Vec<u8>The node’s public key in bytes (ML-DSA-65)
signature: Vec<u8>The node’s signature for the quote (ML-DSA-65)
Implementations
Sourceimpl PaymentQuote
impl PaymentQuote
Sourcepub fn hash(&self) -> FixedBytes<32>
pub fn hash(&self) -> FixedBytes<32>
Compute the hash of this quote.
Sourcepub fn bytes_for_signing(
xorname: XorName,
timestamp: SystemTime,
price: &Uint<256, 4>,
rewards_address: &Address,
) -> Vec<u8> ⓘ
pub fn bytes_for_signing( xorname: XorName, timestamp: SystemTime, price: &Uint<256, 4>, rewards_address: &Address, ) -> Vec<u8> ⓘ
Returns the bytes to be signed from the given parameters.
Sourcepub fn bytes_for_sig(&self) -> Vec<u8> ⓘ
pub fn bytes_for_sig(&self) -> Vec<u8> ⓘ
Returns the bytes to be signed from self.